@@ -1,5 +1,5 @@
 package Business::AuthorizeNet::CIM;
-$Business::AuthorizeNet::CIM::VERSION = '0.10';
+$Business::AuthorizeNet::CIM::VERSION = '0.11';
 
 # ABSTRACT: Authorize.Net Customer Information Manager (CIM) Web Services API
 
@@ -18,7 +18,7 @@ sub new {
     $args->{login}          or croak 'login is required';
     $args->{transactionKey} or croak 'transactionKey is required';
 
-    if ( $args->{test_mode} ) {
+    if ( $args->{test_mode} || $args->{test_host_only} ) {
         $args->{url} = 'https://apitest.authorize.net/xml/v1/request.api';
     }
     else {
@@ -127,8 +127,13 @@ sub createCustomerProfile {
     }
 
     $writer->endTag('profile');
-    if ( $need_payment_profiles && $self->{test_mode} ) {
-        $writer->dataElement( 'validationMode', 'testMode' );
+    if ($need_payment_profiles) {
+        if ( $self->{test_mode} ) {
+            $writer->dataElement( 'validationMode', 'testMode' );
+        }
+        else {
+            $writer->dataElement( 'validationMode', 'liveMode' );
+        }
     }
     $writer->endTag('createCustomerProfileRequest');
 
@@ -204,6 +209,9 @@ sub createCustomerPaymentProfileRequest {
     if ( $self->{test_mode} ) {
         $writer->dataElement( 'validationMode', 'testMode' );
     }
+    else {
+        $writer->dataElement( 'validationMode', 'liveMode' );
+    }
     $writer->endTag('createCustomerPaymentProfileRequest');
 
     $xml = '<?xml version="1.0" encoding="utf-8"?>' . "\n" . $xml;
@@ -275,7 +283,7 @@ sub createCustomerProfileTransaction {
     $writer->startTag('transaction');
     $writer->startTag($trans_type)
       ;    # profileTransAuthOnly, profileTransPriorAuthCapture etc
-    $writer->dataElement( 'amount', $args->{amount} );
+    $writer->dataElement( 'amount', $args->{amount} ) if exists $args->{amount};
 
     foreach my $type ( 'tax', 'shipping', 'duty' ) {
         next unless exists $args->{$type};
@@ -309,7 +317,8 @@ sub createCustomerProfileTransaction {
 
     $writer->dataElement( 'customerProfileId', $args->{customerProfileId} );
     $writer->dataElement( 'customerPaymentProfileId',
-        $args->{customerPaymentProfileId} );
+        $args->{customerPaymentProfileId} )
+      if $args->{customerPaymentProfileId};
     $writer->dataElement( 'customerShippingAddressId',
         $args->{customerShippingAddressId} )
       if $args->{customerShippingAddressId};
@@ -690,6 +699,9 @@ sub updateCustomerPaymentProfile {
     if ( $self->{test_mode} ) {
         $writer->dataElement( 'validationMode', 'testMode' );
     }
+    else {
+        $writer->dataElement( 'validationMode', 'liveMode' );
+    }
     $writer->endTag('updateCustomerPaymentProfileRequest');
 
     $xml = '<?xml version="1.0" encoding="utf-8"?>' . "\n" . $xml;
@@ -822,7 +834,7 @@ Business::AuthorizeNet::CIM - Authorize.Net Customer Information Manager (CIM) W
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -866,6 +878,10 @@ The valid Transaction Key for the developer test or merchant account
 
 validationMode as testMode or liveMode
 
+=item * test_host_only
+
+use test api host and keep default validationMode
+
 =item * ua_args
 
 passed to LWP::UserAgent
